'use strict';

var clientBedrockRuntime = require('@aws-sdk/client-bedrock-runtime');
var embeddings = require('@langchain/core/embeddings');

class BedrockCohereEmbeddings extends embeddings.Embeddings {
  model;
  client;
  batchSize = 512;
  constructor(fields) {
    super(fields ?? {});
    this.model = fields?.model ?? "cohere.embed-english-v3";
    this.client = fields?.client ?? new clientBedrockRuntime.BedrockRuntimeClient({
      region: fields?.region,
      credentials: fields?.credentials
    });
  }
  /**
   * Embeds an array of documents using the Bedrock model.
   * @param documents The array of documents to be embedded.
   * @param inputType The input type for the embedding process.
   * @returns A promise that resolves to a 2D array of embeddings.
   * @throws If an error occurs while embedding documents with Bedrock.
   */
  async embed(documents, inputType) {
    return this.caller.call(async () => {
      const batchSize = 66;
      const batches = [];
      for (let i = 0; i < documents.length; i += batchSize) {
        batches.push(documents.slice(i, i + batchSize));
      }
      const results = [];
      try {
        for (const batch of batches) {
          const res = await this.client.send(
            new clientBedrockRuntime.InvokeModelCommand({
              modelId: this.model,
              body: JSON.stringify({
                texts: batch.map((doc) => doc.replace(/\n+/g, " ")),
                input_type: inputType
              }),
              contentType: "application/json",
              accept: "application/json"
            })
          );
          const body = new TextDecoder().decode(res.body);
          const embeddings = JSON.parse(body).embeddings;
          results.push(...embeddings);
        }
        return results;
      } catch (e) {
        console.error({
          error: e
        });
        if (e instanceof Error) {
          throw new Error(
            `An error occurred while embedding documents with Bedrock: ${e.message}`
          );
        }
        throw new Error(
          "An error occurred while embedding documents with Bedrock"
        );
      }
    });
  }
  async embedQuery(document) {
    return this.embed([document], "search_query").then(
      (embeddings) => embeddings[0]
    );
  }
  async embedDocuments(documents) {
    return this.embed(documents, "search_document");
  }
}

exports.BedrockCohereEmbeddings = BedrockCohereEmbeddings;
//# sourceMappingURL=BedrockCohereEmbeddings.cjs.js.map
